#!/usr/bin/env python
#-*- coding: iso-8859-15 -*-

#################################################################################
## Coban - Module de calcul de section de cable                                ## 
## Copyright (C) 2008  Stphan GURIN                                          ##
## contact : setthe@tuxfamily.org                                              ##
##                                                                             ##
## This program is free software; you can redistribute it and/or               ##
## modify it under the terms of the GNU General Public License                 ##
## as published by the Free Software Foundation; either version 2              ##
## of the License, or (at your option) any later version.                      ##
##                                                                             ##
## This program is distributed in the hope that it will be useful,             ##
## but WITHOUT ANY WARRANTY; without even the implied warranty of              ##
## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               ##
## GNU General Public License for more details.                                ##
##                                                                             ##
## You should have received a copy of the GNU General Public License           ##
## along with this program; if not, write to the Free Software                 ##
## Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. ##
#################################################################################

import wx

############################################################################
##                                                                        ##
##                       Module Section de cble                          ##
##                          Version 0.1.2                                 ##
##    - eye-candy !                                                       ##
##                                                                        ##
##                                                                        ##
############################################################################

version = 'Sections 0.1.2'
sectCu = ' 1.5 2.5 4 6 10 16 25  35 50 70 95 120 150 185 240 300 400 500 630'.split()
sectAlu = '25 35 50 70 95 120 150 185 240 300 400 630'.split()

class ModuleSection(wx.Frame):
    """Calcul des sections de cble"""
    def __init__(self, parent):
        wx.Frame.__init__(self, parent, -1, title = version,
                      style=wx.DEFAULT_FRAME_STYLE 
                      ^(wx.RESIZE_BORDER | wx.MAXIMIZE_BOX))
        self.parent = parent
        
        ############## Cration du panel #########################
        
        panel =  wx.Panel(self, -1, style = wx.TAB_TRAVERSAL
                     | wx.CLIP_CHILDREN
                     | wx.FULL_REPAINT_ON_RESIZE
                     )
        #panel.SetBackgroundColour('white')        
        
        ############## cration du sizer principal ###############
        
        self.gbs = wx.GridBagSizer(hgap=5, vgap=5)
        
        ############## Cration de statusbar #####################
        
        self.CreateStatusBar()
        self.SetStatusText("Consultez l'aide pour plus d'infos...")
        
        
        ############## Cration des widgets ######################
        
        # choix des mtaux
        liste1 = ['Cuivre', 'Aluminium']
        self.metal = wx.RadioBox(panel, -1, u' Type de cble ', (-1, -1), wx.DefaultSize, 
                    liste1, 1, style = wx.RA_SPECIFY_COLS)
        self.metal.SetToolTipString(u'Choix du mtal des conducteurs')
        self.Bind(wx.EVT_RADIOBOX, self.onCalcul, self.metal)
        
        # Choix tension
        liste2 = [u'240V monophas', u'400V triphas cos Phi = 0,8']
        self.tension = wx.RadioBox(panel, -1, u' Tension ', (-1, -1), wx.DefaultSize,
                    liste2, 1, wx.RA_SPECIFY_COLS)
        self.tension.SetToolTipString(u"Choix de la tension d'alimentation")
        self.Bind(wx.EVT_RADIOBOX, self.onChute, self.tension)
        
        # Chute de tension
        self.labelChute = wx.StaticText(panel, -1, 'Chute de tension (en %) :')
        self.chute = wx.SpinCtrl(panel, -1, "", size=(50,-1))
        self.chute.SetRange(1,9)
        self.chute.SetValue(3)
        self.Bind(wx.EVT_SPINCTRL, self.onCalcul, self.chute)
        
        # Saisie de la longueur de cable
        self.labelLg = wx.StaticText(panel, -1, u'Longueur du cble (en mtres) :')
        self.lg = wx.SpinCtrl(panel, -1, "", size=(50,-1))
        self.lg.SetRange(1, 999)
        self.lg.SetValue(100)
        self.Bind(wx.EVT_SPINCTRL, self.onCalcul, self.lg)
        
        # Saisie de l'intensit
        self.labelI = wx.StaticText(panel, -1, u'Intensit (en Ampres) :')    
        self.intensite = wx.SpinCtrl(panel, -1, "", size=(50,-1))
        self.intensite.SetRange(1,650)
        self.intensite.SetValue(50)
        self.Bind(wx.EVT_SPINCTRL, self.onCalcul, self.intensite)
        
        # sparation
        sep = wx.BoxSizer(wx.VERTICAL)
        sep.Add(wx.StaticLine(panel), 0, wx.EXPAND|wx.ALL, 5)
        
        # Fentre des rsultats
        self.labelResult = wx.StaticText(panel, -1, u"Section calcule :", style=wx.ALIGN_RIGHT)
        self.Result = wx.StaticText(panel, -1, '... mm2')
        self.Result.SetForegroundColour('red')
        self.Result.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        # Fentre sections prconises
        self.labelPreco = wx.StaticText(panel, -1, u"Section normalise :", style=wx.ALIGN_RIGHT)
        self.preco = wx.StaticText(panel, -1, '... mm2')
        self.preco.SetForegroundColour('blue')
        self.preco.SetFont(wx.Font(12, wx.SWISS, wx.NORMAL, wx.BOLD))
        
        # bouton Quitter
        self.btnQuit = wx.Button(panel, -1, "Quitter")
        self.btnQuit.SetToolTipString("Quitter l'application...")
        self.Bind(wx.EVT_BUTTON, self.onQuitter, self.btnQuit)
        
        self.Bind(wx.EVT_CLOSE, self.onQuitter)
        
        # logo de l'application
        #pos = 100
        #img = wx.Image(opj(logo), wx.BITMAP_TYPE_PNG).ConvertToBitmap()
        #pos = pos + img.GetHeight() + 10
        #self.logo = wx.StaticBitmap(panel, -1, img, (10, pos), (img.GetWidth(), img.GetHeight()))
        
        ############### Ajout des wigets au sizer ####################
        
        self.gbs.Add(self.metal, (0, 0))
        self.gbs.Add(self.tension, (0, 1))
        self.gbs.Add(self.labelChute, (1, 0))
        self.gbs.Add(self.chute, (1, 1))
        self.gbs.Add(self.labelI, (2, 0))
        self.gbs.Add(self.intensite, (2, 1))
        self.gbs.Add(self.labelLg, (3,0))
        self.gbs.Add(self.lg, (3,1))
        self.gbs.Add(sep, (4,0), (1,4), wx.EXPAND)
        self.gbs.Add(self.labelResult, (5,0))
        self.gbs.Add(self.Result, (5,1))
        self.gbs.Add(self.labelPreco, (6,0))
        self.gbs.Add(self.preco, (6,1))
        self.gbs.Add(self.btnQuit, (7,3))
        #self.gbs.Add(self.logo, (8,0))        
        
        panel.SetSizerAndFit(self.gbs)
        self.SetClientSize(panel.GetSize())
        
        

    def onChute(self, evt):
        tens = self.tension.GetStringSelection()
        if tens == u'240V monophas':
            self.chute.SetValue(3)
        else :
            self.chute.SetValue(5)
        self.onCalcul(evt)
        
    def onCalcul(self, evt):
        
        # choix de ro selon le type de cble
        m = self.metal.GetStringSelection()
        if m == 'Cuivre':
            ro = 23
            sect = sectCu
        else : 
            ro = 37
            sect = sectAlu
        
        # choix de la chute de tension en %
        deltau = self.chute.GetValue()
        if deltau == 0:
            deltau = 3
        
        # choix de la chute de tension en Volts, du coef b, de lbda
        v = self.tension.GetStringSelection()
        if v == u'240V monophas':
            u = deltau*2400
            b = 2
            lbda = 0.13
            cosphi = 1
            sinphi = 0
        else :         
            u = deltau*2400
            b = 1
            lbda = 0.08
            cosphi = 0.8
            sinphi = 0.6
                
        # choix intensit
        i = self.intensite.GetValue()
        if i == 0:
            i = 50
        
        # choix longueur de cble
        l = self.lg.GetValue()
        if l == 0:
            l = 100
             
        # calcul de la section s
        s = (ro*l*cosphi)/((u/(b*i))-(lbda*l*sinphi))
        s = round (s, 2)
        
        if s >= 631 or s < 0 :
            self.Result.SetLabel(u'section non calcule')
            self.preco.SetLabel(u'section non dfinie')
        else :
            # affiche la section calcule
            self.Result.SetLabel('%s mm2' %s)
            # choix de la section normalise
            a = 0            
            sectPreco = sect[a]
            for sectNorm in sect :
                if float(sectNorm) < s:
                    sectPreco = sect[a+1]
                a += 1
            # affiche la section normalise surieure  la section calcule
            self.preco.SetLabel('%s mm2' %sectPreco)
        

    def onQuitter(self, evt):
        """Quitter l'application"""
        self.parent.btnSect.Enable(True)
        self.parent.menuModuleSection.Enable(True)
        self.Destroy()